==> haskell-code-page-0.1.2-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-code-page.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: code-page
version: 0.1.2
id: code-page-0.1.2-JUSY2SsvUe26afmRK8ojg2
key: code-page-0.1.2-JUSY2SsvUe26afmRK8ojg2
license: BSD3
copyright: (C) 2016-2017 Ryan Scott
maintainer: Ryan Scott <ryan.gl.scott@gmail.com>
stability: Provisional
homepage: https://github.com/RyanGlScott/code-page
synopsis: Windows code page library for Haskell
description:
    This library provides two modules:
    .
    * "System.IO.CodePage": a cross-platform module that exports
    functions which adjust code pages on Windows, and do nothing
    on other operating systems.
    .
    * "System.Win32.CodePage": On Windows, this exports functions
    for getting, setting, and analyzing code pages. On other
    operating systems, this module exports nothing.
category: System
author: Ryan Scott
exposed: True
exposed-modules:
    System.IO.CodePage System.Win32.CodePage
abi: 5df956da9bfe9dddcbddb89476f82a70
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/code-page-0.1.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/code-page-0.1.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/code-page-0.1.2
hs-libraries: HScode-page-0.1.2-JUSY2SsvUe26afmRK8ojg2
depends:
    base-4.9.0.0
haddock-interfaces: /usr/share/doc/haskell-code-page/html/code-page.haddock
haddock-html: /usr/share/doc/haskell-code-page/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-code-page-0.1.3-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-code-page.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: code-page
version: 0.1.3
id: code-page-0.1.3-4Xob7qJDA6VAZKPymJS77x
key: code-page-0.1.3-4Xob7qJDA6VAZKPymJS77x
license: BSD3
copyright: (C) 2016-2017 Ryan Scott
maintainer: Ryan Scott <ryan.gl.scott@gmail.com>
stability: Provisional
homepage: https://github.com/RyanGlScott/code-page
synopsis: Windows code page library for Haskell
description:
    This library provides two modules:
    .
    * "System.IO.CodePage": a cross-platform module that exports
    functions which adjust code pages on Windows, and do nothing
    on other operating systems.
    .
    * "System.Win32.CodePage": On Windows, this exports functions
    for getting, setting, and analyzing code pages. On other
    operating systems, this module exports nothing.
category: System
author: Ryan Scott
exposed: True
exposed-modules:
    System.IO.CodePage System.Win32.CodePage
abi: 84ff6cb0ec198eb7cb9d6143c370cb96
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/code-page-0.1.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/code-page-0.1.3
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/code-page-0.1.3
hs-libraries: HScode-page-0.1.3-4Xob7qJDA6VAZKPymJS77x
depends:
    base-4.9.0.0
haddock-interfaces: /usr/share/doc/haskell-code-page/html/code-page.haddock
haddock-html: /usr/share/doc/haskell-code-page/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
